@@ -1,5 +1,5 @@
-require(poweRlaw)
-##Load in the full Moby dick data set
+require("poweRlaw")
+## Load in the full Moby dick data set
 data(moby)
 
 ##Create a distribution object
@@ -25,10 +25,8 @@ m$setXmin(est)
 lines(m, col=4)
 
 ##Uncertainity in xmin
-bs1 = bootstrap(m, no_of_sims=5000, threads=2)
-bs2 = bootstrap_p(m, no_of_sims=5000, threads=2)
-
-
+bs1 = bootstrap(m, no_of_sims=100, threads=2)
+bs2 = bootstrap_p(m, no_of_sims=100, threads=2)
 
 ##This can take a while
 bs1 = bootstrap(m, no_of_sims=5000, threads=4, pars = seq(1.6, 2.5, 0.01))
@@ -39,7 +37,6 @@ par(mfrow=c(1, 2))
 hist(bs1$bootstraps[,2], breaks="fd")
 hist(bs1$bootstraps[,3], breaks="fd")
 
-
 hist(bs2$bootstraps[,2], breaks="fd")
 hist(bs2$bootstraps[,3], breaks="fd")
 
